<?php
/** Eastern Canadian (Aboriginal syllabics) (ᐃᓄᒃᑎᑐᑦ)
 *
 * See MessagesQqq.php for message documentation incl. usage of parameters
 * To improve a translation please visit http://translatewiki.net
 *
 * @ingroup Language
 * @file
 *
 */

$messages = array(
# User preference toggles
'tog-rememberpassword' => 'ᐃᖅᑑ ᐅᐃᑭᐱᑎᐊ ᐊᑎᖅ ᖃᑯᒍᖅ ᐊᑐᐃᓐᓇᓯᕗᖅ ᐅᕙᓗᒪᔪᖅ ᖃᕆᑕᐅᔭᖅ (for a maximum of $1 {{PLURAL:$1|day|days}})',

# Dates
'sunday'        => 'ᓴᓇᑦᑕᐃᓕ',
'monday'        => 'ᓇᒡᒐᔭᖅ',
'wednesday'     => 'ᐱᖓᔪᐊ',
'friday'        => 'ᐸᒐᐃᑖᒃ',
'sun'           => 'ᓴᓇ',
'mon'           => 'ᓇᒡ',
'tue'           => 'ᐱᖃ',
'wed'           => 'ᐱᖓ',
'thu'           => 'ᕿᑎ',
'fri'           => 'ᐅᓪᓗ',
'sat'           => 'ᓯᕙᑕ',
'january'       => 'ᔭᓐᓄᐊᓕ',
'february'      => 'ᕕᐳᐊᕆ',
'march'         => 'ᒫᕐᓯ',
'april'         => 'ᐊᐃᐳᕆᓪ',
'may_long'      => 'ᒪᐃ',
'june'          => 'ᔪᓂ',
'july'          => 'ᔪᓚᐃ',
'august'        => 'ᐊᐅᒍᔅ',
'september'     => 'ᓯᑎᒻᐳᕆ',
'october'       => 'ᐅᒃᑐᐳᕆ',
'november'      => 'ᓄᕕᒻᐳᕆ',
'december'      => 'ᑎᓯᒻᐳᕆ',
'january-gen'   => 'ᔭᓐᓄᐊᓕ',
'february-gen'  => 'ᕕᐳᐊᕆ',
'march-gen'     => 'ᒫᕐᓯ',
'april-gen'     => 'ᐊᐃᐳᕆᓪ',
'may-gen'       => 'ᒪᐃ',
'june-gen'      => 'ᔪᓂ',
'july-gen'      => 'ᔪᓚᐃ',
'august-gen'    => 'ᐊᐅᒍᔅ',
'september-gen' => 'ᓯᑎᒻᐳᕆ',
'october-gen'   => 'ᐅᒃᑐᐳᕆ',
'november-gen'  => 'ᓄᕕᒻᐳᕆ',
'december-gen'  => 'ᑎᓯᒻᐳᕆ',
'jan'           => 'ᔭᓐᓄ',
'feb'           => 'ᕕᐳᐊ',
'mar'           => 'ᓇᑦᓯ',
'apr'           => 'ᐊᐃᐳ',
'may'           => 'ᒪᐃ',
'jun'           => 'ᔪᓂ',
'jul'           => 'ᔪᓚᐃ',
'aug'           => 'ᐊᐅᒍ',
'sep'           => 'ᓯᑎᒻ',
'oct'           => 'ᐅᒃᑐ',
'nov'           => 'ᓄᕕ',
'dec'           => 'ᑎᓯᒻ',

'about'         => 'ᒥᒃᓵᓂ',
'article'       => 'ᐃᓗᓕᒃ ᒪᑉᐱᑕᖅ',
'newwindow'     => '(ᐅᐃᑦᑐᖅ ᖃᕋᓴᐅᔭᖅ ᐃᑭᐊᖅ ᐱᒋᕗᖅ ᐃᒐᓛᖅ)',
'cancel'        => 'ᐃᓂᖅᑎᐹ',
'moredotdotdot' => 'ᐱᓪᓗᐊᕆᕚ...',
'mypage'        => 'ᐊᒥ ᒪᑉᐱᑕᖅ',
'mytalk'        => 'ᐊᓪᓚᖁᑎᒃᑲ',
'navigation'    => 'ᒥᐊᓂᕆᕚ',
'and'           => '&#32;ᐊᒻᒪ',

# Cologne Blue skin
'qbedit'         => 'ᓱᖁᓯᖅᐹ',
'qbspecialpages' => 'ᐱᔨ ᒪᑉᐱᑕᖅ',

'errorpagetitle'    => 'ᑕᒻᒪᓇᖅᑐᖅ',
'help'              => 'ᖃᔭᓕᑉᐹ',
'search'            => 'ᐃᕚᖅᐳᖅ',
'searchbutton'      => 'ᐃᕚᖅᐳᖅ',
'go'                => 'ᐊᐃᕗᖅ',
'searcharticle'     => 'ᐊᐃᕗᖅ',
'history_short'     => 'ᒪᑉᐱᑕᖅ ᑭᖑᓂᑦᑎᓐᓂ',
'edit'              => 'ᓱᖁᓯᖅᐹ',
'editthispage'      => 'ᓱᖁᓯᖅᐹ ᒪᑉᐱᑕᖅ',
'delete'            => 'ᓂᐸᖅᑎᐹ',
'protect'           => 'ᓴᐳᒻᒥᕚ',
'unprotect'         => 'ᐃᖅ ᓴᐳᒻᒥᕚ',
'unprotectthispage' => 'ᐃᖅ ᓴᐳᒻᒥᕚ ᒪᑉᐱᑕᖅ',
'newpage'           => 'ᐱᒋᕗᖅ ᒪᑉᐱᑕᖅ',
'talkpagelinktext'  => 'ᐅᖃᓕᒪᔪᖅ',
'specialpage'       => 'ᐱᔨ ᒪᑉᐱᑕᖅ',
'articlepage'       => 'ᐅᕝᕙ ᐃᓗᓕᒃ ᒪᑉᐱᑕᖅ',
'talk'              => 'ᐅᖃᓕᒪᔪᖅ',
'toolbox'           => 'ᓴᓇᕐᖁᑎᖃᐅᑎ',
'otherlanguages'    => 'ᑭᓪᓗᒧᑦ ᐅᐃᑭ',
'redirectedfrom'    => '(ᖃᓂᖓᓂ ᑲᒪᒋᔭᖅ ᐋᓯᑦ ᓇᑭᑦ $1)',
'redirectpagesub'   => 'ᖃᓂᖓᓂ ᑲᒪᒋᔭᖅ ᐋᓯᑦ ᓇᑭᑦ ᒪᑉᐱᑕᖅ',
'jumptonavigation'  => 'ᒥᐊᓂᕆᕚ',
'jumptosearch'      => 'ᐃᕚᖅᐳᖅ',

# All link text and link target definitions of links into project namespace that get used by other message strings, with the exception of user group pages (see grouppage) and the disambiguation template definition (see disambiguations).
'aboutsite'            => 'ᒥᒃᓵᓂ {{SITENAME}}',
'aboutpage'            => 'Project:ᒥᒃᓵᓂ',
'currentevents'        => 'ᐱᒋᕗᖅ ᐱᐅᓯᖅ',
'currentevents-url'    => 'Project:ᐱᒋᕗᖅ ᐱᐅᓯᖅ',
'edithelp'             => 'ᓱᖁᓯᖅᐹ ᐃᑯᕐᕆᐹ',
'edithelppage'         => 'Help:ᐃᑯᕐᕆᐹ',
'mainpage'             => 'ᐊᒥᖅ',
'mainpage-description' => 'ᐊᒥᖅ',
'portal'               => 'ᖃᒡᒋᖅ',
'portal-url'           => 'Project:ᖃᒡᒋᖅ',
'privacy'              => 'ᓇᒻᒥᓂᖅ ᐱᓕᕆᕝᕕᖃᐅᖅᑐᓄᑦ ᐊᐅᓚᑕᐅᔪᑦ ᐊᑐᐊᒐᖅ, ᐱᓇᓱᐊᕐᓂᖅ',
'privacypage'          => 'Project:ᓇᒻᒥᓂᖅ ᐱᓕᕆᕝᕕᖃᐅᖅᑐᓄᑦ ᐊᐅᓚᑕᐅᔪᑦ ᐊᑐᐊᒐᖅ, ᐱᓇᓱᐊᕐᓂᖅ',

'youhavenewmessages'  => 'ᐃᓕᔅᓯ ᐱᒋᕚ $1 ($2).',
'newmessageslink'     => 'ᐱᒋᕗᖅ ᑭᒡᒐᐹ',
'newmessagesdifflink' => 'ᐊᓐᓂᑐᔪᖅ ᐊᓯᐊᙳᑐᖅ',
'editsection'         => 'ᓱᖁᓯᖅᐹ ᐃᓚ',
'editold'             => 'ᓱᖁᓯᖅᐹ',
'editsectionhint'     => 'ᓱᖁᓯᖅᐹ ᐃᓚᖏᐅᑎᑎᑦᓯᒍᑎ: $1',
'showtoc'             => 'ᐊᓚᒃᑲᑎᖅᐹ',
'hidetoc'             => 'ᐃᔨᖅᐳᖅ',
'site-rss-feed'       => '$1 ᕐᔅᔅ ᒥᐊᓂᕆᕚ',
'site-atom-feed'      => '$1 ᐊᑐᒻ ᒥᐊᓂᕆᕚ',
'page-rss-feed'       => '"$1" ᕐᔅᔅ ᒥᐊᓂᕆᕚ',
'page-atom-feed'      => '"$1" ᐊᑐᒻ ᒥᐊᓂᕆᕚ',

# Short words for each namespace, by default used in the namespace tab in monobook
'nstab-main'      => 'ᒪᑉᐱᑕᖅ',
'nstab-user'      => 'ᐃᓄᒃ ᒪᑉᐱᑕᖅ',
'nstab-special'   => 'ᐱᔨ',
'nstab-project'   => 'ᐱᓕᕆᐊᒃᓴᐃᑦ ᐱᕙᓪᓕᐊᔾᔪᑎᒃᓴᓄᑦ ᒪᑉᐱᑕᖅ',
'nstab-image'     => 'ᐊᒋᐅᑦ',
'nstab-mediawiki' => 'ᑭᒡᒐᐹ',
'nstab-template'  => 'ᒥᐊᓂᕆᕚ-ᕿᔪᖁᑦ',
'nstab-category'  => 'ᓄᐊᑉᐳᑦ',

# General errors
'badtitle'         => 'ᐊᔪᖅᑐᖅ ᐊᑎᖅ',
'editinginterface' => "'''ᐃᓂᖅᑎᕈᑎ—''' ᐋᕼᐊ ᓱᖁᓯᖅᐹ ᐃᑭᐊᖅ ᒪᑉᐱᑕᖅ ᐊᑐᐃᓐᓇᓯᕗᖅ ᐄᔭᑦᓴᖅ ᖃᕋᓴᐅᔭᖅ ᑕᖅᓴᓕᖅᐹ ᐃᑭᐊᖅ ᐊᕿᑦᑐᖅ ᖃᕆᑕᐅᔭᐅᑉ ᑎᑎᕋᕐᕕᖓ. ᐊᓯᐊᙳᑐᖅ ᐃᑭᐊᖅ ᒪᑉᐱᑕᖅ ᐃᓄᒃᑎᑐᑦ ᐅᐃᑭᐱᑎᐊ ᐊᓪᓚᖑᖅᑐᐊᖅ ᓇᑭᒪᖅᐳᖅ ᖃᑕᙳᑎ.",

# Login and logout pages
'welcomecreation'    => "== ᐊᕆᐅᙵᐃᐹ, $1! ==
ᐱᒋᕗᖅ ᖃᑕᙳᑎ ᐅᐃᑭᐱᑎᐊ ᑮᓇᐅᔭᖁᑎᖃᕐᕕᒃ ᐃᓱᐃᓪᓕᖓᐃᑦᔭᐹ. ᐃᖅᑑ ᓱᖁᓯᖅᐹ {{SITENAME}} ᐃᓐᓂᐊᑐᖅ «''ᓂᐱ ᐊᒥ''»",
'yourname'           => 'ᐅᐃᑭᐱᑎᐊ ᐊᑎᖅ',
'yourpassword'       => 'ᐅᐃᑭᐱᑎᐊ ᐸᓚᙵᓴᐅᑎ',
'yourpasswordagain'  => 'ᑕᒪᑐᒪᓃᖅᐹ ᐃᒃᓯᒐᖅᑐᖅ ᐅᐃᑭᐱᑎᐊ ᐸᓚᙵᓴᐅᑎ',
'remembermypassword' => 'ᐃᖅᑑ ᐅᐃᑭᐱᑎᐊ ᐊᑎᖅ ᖃᑯᒍᖅ ᐊᑐᐃᓐᓇᓯᕗᖅ ᐅᕙᓗᒪᔪᖅ ᖃᕆᑕᐅᔭᖅ (for a maximum of $1 {{PLURAL:$1|day|days}})',
'login'              => 'ᐊᑯᓐᓇᐳᖅ',
'loginprompt'        => 'ᐱᒋᐊᓕᒃ ᐃᒪᑐᐊᖅ ᖃᕆᑕᐅᔭᖅ ᖂᑮᔅ(Cookies) ᐱᕐᖄᑎ ᐊᑯᓐᓇᐳᖅ ᐅᐃᑭᐱᑎᐊ.',
'userlogin'          => 'ᐊᑯᓐᓇᐳᖅ / ᐱᕐᖄᐹ ᑮᓇᐅᔭᒃᑯᕕᖕᒥ ᑐᖅᑯᖅᓯᕕᒃ',
'logout'             => 'ᐊᓂᕝᕕᒃ',
'userlogout'         => 'ᐊᓂᕝᕕᒃ',
'nologin'            => "ᐊᔪᐃᓐᓈᖅ ᐃᓄᖁᑎ? '''$1'''.",
'nologinlink'        => 'ᐱᕐᖄᐹ ᑮᓇᐅᔭᒃᑯᕕᖕᒥ ᑐᖅᑯᖅᓯᕕᒃ',
'gotaccountlink'     => 'ᐊᑯᓐᓇᐳᖅ',
'mailmypassword'     => 'ᕿᓪᓗᑐᖅ ᐅᐃᑭᐱᑎᐊ ᐸᓚᙵᓴᐅᑎ ᑭᒍᑎᐅᑉ ᓯᑎᓂᖅᐹᖓ',

# Edit page toolbar
'bold_sample' => 'ᐃᔾᔪᔪᒡ ᑕᖅᓴᓕᖅᐹ',
'bold_tip'    => 'ᐃᔾᔪᔪᒡ ᑕᖅᓴᓕᖅᐹ',

# Edit pages
'summary'         => 'ᓱᕕᑦ:',
'minoredit'       => 'ᐅᑭᐅᑭᓗᐊᖅᑐᖅ ᐊᓯᐊᙳᑐᖅ',
'watchthis'       => 'ᐅᕝᕙ',
'savearticle'     => 'ᐅᖃᐅᓯᓪᓚᕆᖏᑕ ᑎᑎᕋᖅᑕᐅᓂᖏᑦ',
'preview'         => 'ᐅᕝᕙ ᖃᖓᓵᖑᓕᖅᑐᖅ',
'showpreview'     => 'ᓱᖁᓯᖅᐹ ᐊᓚᒃᑲᐅᑎᕗᖅ ᓯᕗᓕᐅᖅᐹ ᐅᖃᐅᓯᓪᓚᕆᖏᑕ ᑎᑎᕋᖅᑕᐅᓂᖏᑦ',
'showdiff'        => 'ᐊᓚᒃᑲᑎᑉᐹ ᐊᓯᐊᙳᑐᖅ',
'summary-preview' => 'ᓱᕕᑦ:',
'blockedtitle'    => 'ᐋᖅᑭᒃᓱᐃᔨ ᐅᒥᙵᓯᓯᔪᖅ',
'loginreqlink'    => 'ᐊᑯᓐᓇᐳᖅ',
'newarticle'      => '(ᐱᒋᕗᖅ)',
'editing'         => 'ᐊᓯᐊᙳᑐᖅ $1',
'editingsection'  => 'ᓱᖁᓯᖅᐹ ᐃᓚ $1 (ᖏᐅᑎᑎᑦᓯᒍᑎ)',
'editingcomment'  => 'ᓱᖁᓯᖅᐹ $1 (ᐅᔾᔨᕆᔭᖅ)',
'editconflict'    => 'ᓱᖁᓯᖅᐹ ᐊᑲᐅᙱᓕᐅᕈᑎᓂᖅ: $1',

# History pages
'currentrev'          => 'ᒫᓐᓇ ᑎᑎᕋᖅᑕᐅᒋᐊᕐᖓᕈᑦ',
'previousrevision'    => '←ᐅᑐᖃᖅ  ᑎᑎᕋᖅᑕᐅᒋᐊᕐᖓᕈᑦ',
'nextrevision'        => 'ᐱᓪᓗᐊᕆᕚ ᐱᒋᕗᖅ ᑎᑎᕋᖅᑕᐅᒋᐊᕐᖓᕈᑦ→',
'currentrevisionlink' => 'ᒫᓐᓇ ᑎᑎᕋᖅᑕᐅᒋᐊᕐᖓᕈᑦ',
'next'                => 'ᑕᒡᒐ',
'last'                => 'ᐊᓐᓂᑐᔪᖅ',

# Revision feed
'history-feed-title'       => 'ᑎᑎᕋᖅᑕᐅᒋᐊᕐᖓᕈᑦ ᒪᑉᐱᑕᖅ ᑭᖑᓂᑦᑎᓐᓂ',
'history-feed-description' => 'ᑎᑎᕋᖅᑕᐅᒋᐊᕐᖓᕈᑦ ᒪᑉᐱᑕᖅ ᑭᖑᓂᑦᑎᓐᓂ ᐃᑭᐊᖅ ᐅᐃᑭ',

# Diffs
'history-title' => 'ᑎᑎᕋᖅᑕᐅᒋᐊᕐᖓᕈᑦ ᒪᑉᐱᑕᖅ ᑭᖑᓂᑦᑎᓐᓂ "$1"',
'difference'    => '(ᐊᓯᐊᙳᑐᖅ ᒪᑉᐱᑕᖅ ᐊᑯᓐᓂᖓᓐᓂ ᑎᑎᕋᖅᑕᐅᒋᐊᕐᖓᕈᑦ)',
'lineno'        => 'ᑐᑭᖅᓯᖅ $1:',
'editundo'      => 'ᐃᐱᐅᑦᔮᐹ',
'diff-multi'    => '({{PLURAL:$1|ᐊᑕᐅᓯᖅ ᑭᒻᒥᐅᕗᖅ ᑎᑎᕋᖅᑕᐅᒋᐊᕐᖓᕈᑦ|$1 ᑭᒻᒥᐅᕗᖅ ᑎᑎᕋᖅᑕᐅᒋᐊᕐᖓᕈᑦ}} ᐊᔪᖅᑐᖅ ᐅᕝᕙ.)',

# Search results
'nextn'       => 'ᑕᒡᒐ {{PLURAL:$1|$1}}',
'powersearch' => 'ᕿᓐᓇᕆᒃᓴᕐᓂᖅ',

# Preferences page
'mypreferences'     => 'ᐊᒥ ᐱᒃᑯᒪᓂᖅᐹᖅ',
'prefs-rc'          => 'ᐱᒋᕗᖅ ᐊᓯᐊᙳᑐᖅ',
'searchresultshead' => 'ᐃᕚᖅᐳᖅ',
'youremail'         => 'ᑭᒍᑎᐅᑉ ᓯᑎᓂᖅᐹᖓ:',
'username'          => 'ᐅᐃᑭᐱᑎᐊ ᐊᑎᖅ:',
'yourrealname'      => 'ᐃᓄᓪᓚᕆᒃ ᐊᑎᖅ:',
'email'             => 'ᑭᒍᑎᐅᑉ ᓯᑎᓂᖅᐹᖓ',
'prefs-help-email'  => 'ᑭᒍᑎᐅᑉ ᓯᑎᓂᖅᐹᖓ (ᐱᒃᑲᓪᓚᕗᖅ) — ᖃᑯᒍ ᓇᓗᓇᙱᓚᖅ ᐃᓕᔅᓯ ᐱᔪᖕᓇᖅᑐᖅ ᐱᒋᕚ ᑲᙳᓇᖅᑐᖅ ᐋᔩᖃᑎᒋᖏᖅ',

# User rights
'editinguser' => "ᓱᖁᓯᖅᐹ ᖃᑕᙳᑎ '''[[User:$1|$1]]''' ([[User talk:$1|{{int:talkpagelinktext}}]] | [[Special:Contributions/$1|{{int:contribslink}}]])",

# Recent changes
'recentchanges'   => 'ᐱᒋᕗᖅ ᐊᓯᐊᙳᑐᖅ',
'hide'            => 'ᐃᔨᖅᐳᖅ',
'show'            => 'ᐊᓚᒃᑲᑎᖅᐹ',
'minoreditletter' => 'ᐅ',
'newpageletter'   => 'ᐱ',
'boteditletter'   => 'ᑉ',

# Recent changes linked
'recentchangeslinked'          => 'ᐊᓯᐊᙳᑐᖅ ᒥᑦᓵᓯᔪᖅ',
'recentchangeslinked-feed'     => 'ᐊᓯᐊᙳᑐᖅ ᒥᑦᓵᓯᔪᖅ',
'recentchangeslinked-toolbox'  => 'ᐊᓯᐊᙳᑐᖅ ᒥᑦᓵᓯᔪᖅ',
'recentchangeslinked-noresult' => '0 ᐊᓯᐊᙳᑐᖅ ᐃᑦᓯᕕᒻᒥᐅᓯᖅᐹ ᒪᑉᐱᑕᖅ ᑕᑯᕙᓪᓚᑐᖅ ᓱᓪᓗᒃ ᑕᒪᑐᒪᓂ ᑐᒥᑯ',

# Upload
'upload'            => 'ᒪᑉᐱᐹ ᓇᓗᓇᐃᔭᐅᑎᑦ',
'uploadbtn'         => 'ᒪᑉᐱᐹ ᓇᓗᓇᐃᔭᐅᑎᑦ',
'filedesc'          => 'ᐱᓕᕆᐊᒃᓴᑦ ᐱᕕᒡᔪᐊᖑᓂᖏᑦ',
'fileuploadsummary' => 'ᓱᕕᑦ:',
'watchthisupload'   => 'ᐅᕝᕙ',

# File description page
'file-anchor-link' => 'ᐊᒋᐅᑦ',

# List redirects
'listredirects' => 'ᓂᐱ ᖃᓂᖓᓂ ᑲᒪᒋᔭᖅ ᐋᓯᑦ ᓇᑭᑦ',

# Random page
'randompage' => 'ᓇᑭᑐᐃᓐᓇᖅ ᖃᐅᔨᓴᕐᓂᖅ ᒪᑉᐱᑕᖅ',

# Random redirect
'randomredirect' => 'ᓇᑭᑐᐃᓐᓇᖅ ᖃᐅᔨᓴᕐᓂᖅ ᖃᓂᖓᓂ ᑲᒪᒋᔭᖅ ᐋᓯᑦ ᓇᑭᑦ',

# Statistics
'statistics'              => 'ᑭᓯᑦᓯᓯᖕᖑᕐᓗᒋᑦ ᐹᓯᔅᓱᑎᔅᓴᑦ',
'statistics-header-users' => 'ᖃᑕᙳᑎ ᑭᓯᑦᓯᓯᖕᖑᕐᓗᒋᑦ ᐹᓯᔅᓱᑎᔅᓴᑦ',

'doubleredirects' => 'ᑕᐱᕐᖃᓕᒃ ᖃᓂᖓᓂ ᑲᒪᒋᔭᖅ ᐋᓯᑦ ᓇᑭᑦ',

'brokenredirects'        => 'ᓇᐱᕚ ᖃᓂᖓᓂ ᑲᒪᒋᔭᖅ ᐋᓯᑦ ᓇᑭᑦ',
'brokenredirects-edit'   => 'ᓱᖁᓯᖅᐹ',
'brokenredirects-delete' => 'ᓂᐸᖅᑎᐹ',

# Miscellaneous special pages
'listusers'         => 'ᖃᑕᙳᑎ ᓂᐱ',
'newpages-username' => 'ᐅᐃᑭᐱᑎᐊ ᐊᑎᖅ:',
'ancientpages'      => 'ᒪᑉᐱᑕᖅ ᐃᑦᑐᓴᖅ ᐅᑐᖃᖅ',
'move'              => 'ᐅᐊᔪᖅ',

# Book sources
'booksources-go' => 'ᐊᐃᕗᖅ',

# Special:AllPages
'allpages'       => 'ᓱᓇᒥᑦᑐᖅ ᒪᑉᐱᑕᖅ',
'nextpage'       => 'ᑕᒡᒐ ᒪᑉᐱᑕᖅ ($1)',
'allpagesprev'   => 'ᑐᓄᓪᓕᐹᖅ',
'allpagesnext'   => 'ᑕᒡᒐ',
'allpagessubmit' => 'ᐊᐃᕗᖅ',

# Special:Categories
'categories' => 'ᓄᐊᑉᐳᑦ',

# E-mail user
'emailuser'    => 'ᑭᒍᑎᐅᑉ ᓯᑎᓂᖅᐹᖓ ᐃᓄᒃ',
'emailfrom'    => 'ᓇᑭᑦ',
'emailmessage' => 'ᑭᒡᒐᐹ',
'emailsend'    => 'ᕿᐅᑦᓴᕕᒋᕚ',

# Watchlist
'watchlist'     => 'ᐅᕝᕙ ᒪᑉᐱᑕᖅ',
'mywatchlist'   => 'ᓂᐱ ᐊᒥ',
'watch'         => 'ᐅᕝᕙ',
'watchthispage' => 'ᐅᕝᕙ',
'unwatch'       => 'ᐃᖅ ᐅᕝᕙ',

'enotif_impersonal_salutation' => '{{SITENAME}} ᖃᑕᙳᑎ',
'created'                      => 'ᒪᑉᐱᑕᖅ ᐊᓂᕗᖅ',

# Delete
'dellogpage'  => 'ᓂᐸᖅ ᓂᐱ',
'deletionlog' => 'ᓂᐸᖅ ᓂᐱ',

# Protect
'prot_1movedto2'      => '[[$1]] ᓱᕐᕋᒪᔪᖅ [[$2]]',
'protect-legend'      => 'ᐸᑎᒻᒥᕚ ᓴᐳᒻᒥᕚ',
'protect-level-sysop' => 'ᓯᕐᓚᒃ ᑎᑎᕋᖅᓯᒪᔪᓂᒃ ᑐᖅᑯᖅᑎᕆᔨ',

# Restrictions (nouns)
'restriction-move' => 'ᐅᐊᔪᖅ',

# Undelete
'undelete-search-submit' => 'ᐃᕚᖅᐳᖅ',

# Namespace form on various pages
'blanknamespace' => '(ᐊᒥᖅ)',

# Contributions
'mycontris' => 'ᑕᓕᐊᖅ',

'sp-contributions-talk'   => 'ᐅᖃᓕᒪᔪᖅ',
'sp-contributions-submit' => 'ᐃᕚᖅᐳᖅ',

# What links here
'whatlinkshere' => 'ᐅᖅᓯᖅ ᒪᐅᖓ',
'isredirect'    => 'ᑕᐱᑕᕇᒃ ᐅᖅᓯᖅ ᒪᑉᐱᑕᖅ',

# Block/unblock
'blockip'                  => 'ᐃᖅ ᐋᖅᑭᒃᓱᐃᔨ',
'badipaddress'             => 'ᐃᓪᓕᑐᖅ ᖃᕆᓴᐅᔭᒃᑯᑦ ᑎᑎᕋᖅᓯᒪᔪᑦ ᒪᓕᒐᑎᒍᑦ ᐊᖏᕈᑕᐅᓯᒪᔪᖅ ᐅᓂᒃᑳᕆᔭᖃᕐᓂᖅ',
'blockipsuccesssub'        => 'ᐅᒥᙵᓯᓯᔪᖅ ᓈᔪᖅ',
'ipblocklist-submit'       => 'ᐃᕚᖅᐳᖅ',
'anononlyblock'            => 'ᓯᕐᓚᒃ ᐃᓕᓴᕐᓇᙱᑎᑦᑐᖅ',
'blocklink'                => 'ᐃᖅ',
'contribslink'             => 'ᖃᑕᙳᑎ ᓱᖁᓯᖅᐹ',
'blocklogpage'             => 'ᐅᒥᙵᓯᓯᔪᖅ/ᐃᖅ ᑎᑎᖅᑲᖁᑎᑦ ᑐᖅᑯᖅᓯᒪᔭᐃᑦ',
'block-log-flags-anononly' => 'ᐃᓕᓴᕐᓇᙱᑎᑦᑐᖅ ᐋᖅᑭᒃᓱᐃᔨ ᑭᓯᐊᓂ',
'block-log-flags-nocreate' => 'ᑮᓇᐅᔭᖃᕐᕕᒃ ᐃᓄᐃᕈᑎᕚ ᐃᓂᖅᑎᐹ ᐱᒋᕗᖅ',
'block-log-flags-noemail'  => 'ᑭᒍᑎᐅᑉ ᓯᑎᓂᖅᐹᖓ',

# Move page
'move-page-legend' => 'ᐅᐊᔪᖅ ᒪᑉᐱᑕᖅ',
'movearticle'      => 'ᐅᐊᔪᖅ ᒪᑉᐱᑕᖅ',
'movedto'          => 'ᐅᐊᔪᖅ',
'1movedto2'        => '[[$1]] ᓱᕐᕋᒪᔪᖅ [[$2]]',
'1movedto2_redir'  => '[[$1]] ᓱᕐᕋᒪᔪᖅ [[$2]] ᒥᓯᑉᐹ ᖃᓂᖓᓂ ᑲᒪᒋᔭᖅ ᐋᓯᑦ ᓇᑭᑦ',
'movelogpage'      => 'ᐅᐊᔪᖅ ᓂᐱ',
'movereason'       => 'ᐃᓱᒪᒃᓴᖅᓯᐅᕈᓐᓇᑦᑎᐊᕐᓂᖅ:',
'delete_and_move'  => 'ᓂᐸᖅᑎᐹ  ᐊᒻᒪ ᐅᐊᔪᖅ',

# Namespace 8 related
'allmessagesname' => 'ᐊᑎᖅ',

# Import log
'import-logentry-upload-detail'    => '$1 {{PLURAL:$1|ᑎᑎᕋᖅᑕᐅᒋᐊᕐᖓᕈᑦ|ᑎᑎᕋᖅᑕᐅᒋᐊᕐᖓᕈᑦ}}',
'import-logentry-interwiki-detail' => '$1 {{PLURAL:$1|ᑎᑎᕋᖅᑕᐅᒋᐊᕐᖓᕈᑦ|ᑎᑎᕋᖅᑕᐅᒋᐊᕐᖓᕈᑦ}} ᐃᑭᐊᖅ $2',

# Tooltip help for the actions
'tooltip-pt-mytalk'               => 'ᐊᓪᓚᖁᑎᒃᑲ',
'tooltip-pt-preferences'          => 'ᐊᒥ ᐱᒃᑯᒪᓂᖅᐹᖅ',
'tooltip-pt-logout'               => 'ᐊᓂᕝᕕᒃ',
'tooltip-ca-protect'              => 'ᓴᐳᒻᒥᕚ ᒪᑉᐱᑕᖅ',
'tooltip-search'                  => 'ᐃᕚᖅᐳᖅ {{SITENAME}}',
'tooltip-minoredit'               => 'ᑐᐊᐸᖅ ᐊᓯᐊᙳᑐᖅ',
'tooltip-diff'                    => 'ᓱᕐᕋᐹ ᖃᑕᙳᑎ',
'tooltip-compareselectedversions' => 'ᐅᕝᕙ ᐊᓯᐊᙳᑐᖅ ᒪᑉᐱᑕᖅ ᐊᑯᓐᓂᖓᓐᓂ ᒪᕐᕉᒃ ᑎᑎᕋᖅᑕᐅᒋᐊᕐᖓᕈᑦ',

# Attribution
'anonymous' => 'ᐃᓕᓴᕐᓇᙱᑎᑦᑐᖅ ᖃᑕᙳᑎ ᓇᑭᑦ {{SITENAME}}',

# Math errors
'math_unknown_error'    => 'ᑐᓴᐅᒪᔭᐅᙱᑐᖅ ᑕᒻᒪᓇᖅᑐᖅ',
'math_unknown_function' => 'ᑐᓴᐅᒪᔭᐅᙱᑐᖅ ᐃᓕᐅᕐᓂᖅ',

# Image deletion
'deletedrevision' => 'ᓂᐸᖅ ᐅᑐᖃᖅ ᑎᑎᕋᖅᑕᐅᒋᐊᕐᖓᕈᑦ $1',

# Browsing diffs
'previousdiff' => '← ᑐᓄᓪᓕᐹᖅ ᐊᓯᐊᙳᑐᖅ',
'nextdiff'     => 'ᑕᒡᒐ ᐊᓯᐊᙳᑐᖅ ᒪᑉᐱᑕᖅ →',

# Special:NewFiles
'ilsubmit' => 'ᐃᕚᖅᐳᖅ',
'bydate'   => 'ᐱᑖᕈᑦᑐᖅ ᐃᓅᓕᕐᕕᒃ',

# EXIF tags
'exif-imagelength'         => 'ᖁᑦᓯᖕᓂᖅ',
'exif-imagedescription'    => 'ᐃᓄᙳᐊᖅ ᐊᑎᖅ',
'exif-colorspace'          => 'ᒥᖑᐊᕈᑎᒥᑎᖅᐹ',
'exif-datetimeoriginal'    => 'ᖃᑦᓯᐹ ᐊᒪᒻ ᑎᑭᐅᑎ ᓴᕐᕿᐹ ᐃᓱᐃᓪᓕᖓᐃᑦᔭᐹ',
'exif-datetimedigitized'   => 'ᖃᑦᓯᐹ ᐊᒪᒻ ᑎᑭᐅᑎ ᓴᕐᕿᐹ ᖃᕋᓴᐅᔭᖅ',
'exif-exposuretime-format' => '$1 ᐊᐃᑉᐸᖅ ($2)',
'exif-brightnessvalue'     => 'ᖃᐅᒻᒪᐹ ᐊᒃᑭᐅᑕᖅ',

# 'all' in various places, this might be different for inflected languages
'monthsall' => 'ᓱᓇᒥᑦᑐᖅ',

# action=purge
'confirm_purge_button' => 'ᐊᑲᐅᔪᖅ',

# Multipage image navigation
'imgmultipageprev' => '← ᑐᓄᓪᓕᐹᖅ  ᒪᑉᐱᑕᖅ',
'imgmultipagenext' => 'ᑕᒡᒐ ᒪᑉᐱᑕᖅ →',
'imgmultigo'       => 'ᐊᐃᕗᖅ!',

# Table pager
'table_pager_limit_submit' => 'ᐊᐃᕗᖅ',

# Auto-summaries
'autoredircomment' => 'ᖃᓂᖓᓂ ᑲᒪᒋᔭᖅ ᐋᓯᑦ ᓇᑭᑦ [[$1]]',
'autosumm-new'     => 'ᐱᒋᕗᖅ ᒪᑉᐱᑕᖅ: $1',

# Special:SpecialPages
'specialpages' => 'ᐱᔨ ᒪᑉᐱᑕᖅ',

);
